@@ -17,7 +17,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1995 -- 2015, T. V. Raman
+;;; Copyright (C) 1995 -- 2017, T. V. Raman
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -41,9 +41,11 @@
 
 ;;{{{ required modules
 
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 (eval-when-compile
-  (require 'ecb "ecb" 'no-error)
+  (let ((inhibit-message  t))
+  (require 'ecb "ecb" 'no-error))
   (require 'tree-buffer "tree-buffer" 'no-error))
 ;;}}}
 ;;{{{  Introduction:
@@ -72,7 +74,7 @@
     (emacspeak-auditory-icon 'help)
     (emacspeak-speak-mode-line)))
 
-(loop
+(cl-loop
  for f in 
  '(
    ecb-nav-goto-next
@@ -108,7 +110,7 @@
 (defun emacspeak-ecb-tree-backspace ()
   "Back up during incremental search in tree buffers."
   (interactive)
-  (declare (special tree-buffer-incr-searchpattern))
+  (cl-declare (special tree-buffer-incr-searchpattern))
   ;; reduce by one from the end
   (setq tree-buffer-incr-searchpattern
         (substring tree-buffer-incr-searchpattern
@@ -121,7 +123,7 @@
 (defun emacspeak-ecb-tree-clear ()
   "Clear search pattern during incremental search in tree buffers."
   (interactive)
-  (declare (special tree-buffer-incr-searchpattern))  
+  (cl-declare (special tree-buffer-incr-searchpattern))  
   (setq tree-buffer-incr-searchpattern "")
   (dtk-speak "Cleared search pattern."))
 
@@ -176,7 +178,7 @@ available."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-line)))
-(defsubst tree-node-is-expanded (node)
+(defun tree-node-is-expanded (node)
   "Check if node is expanded."
   (or (not (tree-node->expandable node))
       (tree-node->expanded node)))
@@ -269,7 +271,7 @@ available."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: nil
+;;; byte-compile-dynamic: t
 ;;; end:
 
 ;;}}}
